@@ -45,31 +45,6 @@ class DatabaseUserGrants(Resource):
             local_response, models.DatabaseUserGrantResource
         )
 
-    def list_database_user_grants_for_database_users(
-        self,
-        *,
-        database_user_id: int,
-        skip: Optional[int] = None,
-        limit: Optional[int] = None,
-        filter_: Optional[List[str]] = None,
-        sort: Optional[List[str]] = None,
-    ) -> DtoResponse[list[models.DatabaseUserGrantResource]]:
-        local_response = self.api_connector.send_or_fail(
-            "GET",
-            f"/api/v1/database-user-grants/{database_user_id}",
-            data=None,
-            query_parameters={
-                "skip": skip,
-                "limit": limit,
-                "filter": filter_,
-                "sort": sort,
-            },
-        )
-
-        return DtoResponse.from_response(
-            local_response, models.DatabaseUserGrantResource
-        )
-
     def delete_database_user_grant(
         self,
         *,
